==> argous-1.2.235.tgz: package/lib/components/ContactValidationInput/ContactValidationInput.js <==
import './style.css';
import SealModal from './SealModal';
import { OtpInput } from '../';
import { api, headers } from '../../api';
import { numbersOnly, useModal } from '../../utils';
import { setError } from '../../utils/api';
import { Button, CircularProgress, Grid, IconButton, InputAdornment, TextField, Typography, useTheme } from '@material-ui/core';
import React, { useCallback, useEffect, useState } from 'react';
import { IoMdCheckmark } from 'react-icons/io';
import { LiaExclamationTriangleSolid } from 'react-icons/lia';
import { PiSealCheck } from 'react-icons/pi';
import MaskedInput from 'react-maskedinput';


const EMAIL_VALIDATION_REGEX = /^[\w-.]+@([\w-]+\.)+[\w-]{2,4}$/;

const cellphoneMaskedInput = (props) => <MaskedInput mask='(11) 11111-1111' {...props} />;
export const SealIcon = PiSealCheck;

export const GREEN_COLOR = '#00995D';
const ORANGE_COLOR = '#f5781e';
const RED_COLOR = '#f44336';


const INPUT_ADORNMENT_ICON_SIZE = 18;


const loadingInitialState = { 
  input: false, 
  validation: false, 
  sendValidationLink: false 
};

const messageInitialState = { color: '', text: '' };

const initialState = { 
  loading: loadingInitialState, 
  validated: false, 
  validating: false, 
  searched: false, 
  idContato: '', 
  cdContato: '', 
  code: '', 
  message: messageInitialState 
};


const ContactValidationInput = ({ 
  id, 
  type = ('cellphone' || 'email'), 
  textFieldProps = {}, 
  style = {}, 
  className = '', 
  disabled, 
  cpf = '', 
  userName = '', 
  value = '', 
  onChange = () => '', 
  getComponentData = () => '' 
}) => {

  const theme = useTheme();
  const [state, setState] = useState({ ...initialState, inputValue: value });
  const { inputValue, loading, searched, validated, idContato, cdContato, code, message, validating } = state;
  const { createModal } = useModal();
  const sealModal = createModal(SealModal);

  const logicSetState = ({ type, field, value }) => setState((states) => ({ 
    ...states, 
    [type]: (type && field) ? { ...states[type], [field]: value } : value 
  }));

  const cellphoneType = (type === 'cellphone');
  const emailType = (type === 'email');

  const formattedInputValue = (cellphoneType) ? numbersOnly(inputValue) : inputValue;
  const invalidType = (!cellphoneType && !emailType);
  const disabledRule = (disabled || !cpf || !userName || invalidType || loading.input);
  const validatedRule = (searched && validated && !validating);
  const noValidatedRule = ((searched && !validated) || validating);
  const validCellphone = (cellphoneType && (formattedInputValue.length === 11));
  const validEmail = (emailType && (EMAIL_VALIDATION_REGEX.test(inputValue)));
  const sendValidationCodeButtonDisabled = (validCellphone || validEmail) ? false : true;
  const codeWasSent = !!idContato;


  const containerStyle = { gap: 10 };
  const endInputAdornmentStyle = { gap: 7 };

  const messageStyle = { 
    color: (message.color || theme.palette.text.primary), 
    fontStyle: 'italic' 
  };

  const validateCodeButtonsContainerStyle = { gap: 10 };

  const validateCodeButtonStyle = { 
    width: 'calc(100% - 36px - 10px)' 
  };

  const sealButtonStyle = { 
    height: '100%', 
    color: GREEN_COLOR, 
    border: `2px solid ${GREEN_COLOR}`, 
    borderRadius: 4, 
    padding: 5, 
    fontSize: 22 
  };


  const handleOnChange = (event) => {
    event.target.value = event.target.value.toString().toLowerCase();
    logicSetState({ type: 'inputValue', value: event.target.value });
    (typeof onChange === 'function') && onChange(event);
  };

  const search = useCallback(async () => {
    if (invalidType) return;

    logicSetState({ type: 'loading', field: 'input', value: true });

    const parameters = { 
      method: 'S', 
      type: (cellphoneType) ? '1' : (emailType) ? '2' : '', 
      cdCpf: numbersOnly(cpf) 
    };

    const fetchOptions = { 
      method: 'POST', 
      body: JSON.stringify(parameters), 
      headers: headers() 
    };

    const { status, cdContato, isVerificado } = await fetch(`${api()}agscontactconfirmation.rslvr`, fetchOptions).then(async (response) => await response.json());
    if (status) {
      setState((states) => ({ 
        ...states, 
        cdContato, 
        inputValue: (cdContato || ''), 
        searched: true, 
        validated: isVerificado 
      }));
    }

    logicSetState({ type: 'loading', field: 'input', value: false });
  }, [cellphoneType, emailType, invalidType, cpf]);

  useEffect(() => {
    search();
  }, [search]);

  const sendValidationCode = async () => {
    if (invalidType) return;

    logicSetState({ type: 'loading', field: 'input', value: true });

    const parameters = { 
      method: 'C', 
      type: (cellphoneType) ? '1' : (emailType) ? '2' : '', 
      tpMetodo: (emailType) ? '3' : '', 
      cdCpf: numbersOnly(cpf), 
      dsNome: userName, 
      cdContato: formattedInputValue 
    };

    const fetchOptions = { 
      method: 'POST', 
      body: JSON.stringify(parameters), 
      headers: headers() 
    };

    const { status, idContato, cdContato, dsErro } = await fetch(`${api()}agscontactconfirmation.rslvr`, fetchOptions).then(async (response) => await response.json());
    if (status) {
      setState((states) => ({ 
        ...states, 
        idContato, 
        cdContato, 
        validated: false, 
        validating: true, 
        message: { 
          color: ORANGE_COLOR, 
          text: (cellphoneType) ? 'Utilize o código recebido via sms' : (emailType) ? 'Utilize o código recebido via e-mail' : '' 
        } 
      }));
    } else {
      (dsErro) && setError(dsErro);
    }

    logicSetState({ type: 'loading', field: 'input', value: false });
  };

  const sendValidationLink = async () => {
    if (invalidType) return;

    logicSetState({ type: 'loading', field: 'sendValidationLink', value: true });

    const parameters = { 
      method: 'C', 
      type: '2', 
      tpMetodo: '4', 
      cdCpf: numbersOnly(cpf), 
      dsNome: userName, 
      cdContato: formattedInputValue 
    };

    const fetchOptions = { 
      method: 'POST', 
      body: JSON.stringify(parameters), 
      headers: headers() 
    };

    const { status, cdContato, dsErro } = await fetch(`${api()}agscontactconfirmation.rslvr`, fetchOptions).then(async (response) => await response.json());
    if (status) {
      setState((states) => ({ 
        ...states, 
        idContato: '', 
        cdContato, 
        code: '', 
        message: { 
          color: '', 
          text: `O link de validação foi enviado para o e-mail "${cdContato}"` 
        } 
      }));
    } else {
      (dsErro) && setError(dsErro);
    }

    logicSetState({ type: 'loading', field: 'sendValidationLink', value: false });
  };

  const validateCode = async ({ snChancela = false }) => {
    if (invalidType) return;

    logicSetState({ type: 'loading', field: (snChancela) ? 'input' : 'validation', value: true });

    const parameters = { 
      method: 'V', 
      type: (cellphoneType) ? '1' : (emailType) ? '2' : '', 
      cdCpf: numbersOnly(cpf), 
      dsNome: userName, 
      cdCode: code, 
      cdContato: formattedInputValue, 
      idContato, 
      snChancela 
    };

    const fetchOptions = { 
      method: 'POST', 
      body: JSON.stringify(parameters), 
      headers: headers() 
    };

    const { status, isVerificado } = await fetch(`${api()}agscontactconfirmation.rslvr`, fetchOptions).then(async (response) => await response.json());
    if (status) {

      let messageText = '';

      if (isVerificado) {
        if (cellphoneType) messageText = 'Celular validado com sucesso';
        else if (emailType) messageText = 'E-mail validado com sucesso';

        setTimeout(() => logicSetState({ type: 'message', value: messageInitialState }), 6000);
      } else {
        messageText = 'Código inválido. Por favor tente novamente.';
      }

      setState((states) => ({ 
        ...states, 
        validated: isVerificado, 
        validating: false, 
        idContato: '', 
        code: '', 
        message: { 
          color: (isVerificado) ? '' : RED_COLOR, 
          text: messageText 
        } 
      }));
    }

    logicSetState({ type: 'loading', field: (snChancela) ? 'input' : 'validation', value: false });
  };

  const toSeal = async () => {
    const { status } = await sealModal();
    if (status) validateCode({ snChancela: true });
  };

  const checkConsistency = useCallback(() => {
    if ((formattedInputValue === cdContato) && validated) logicSetState({ type: 'validating', value: false });
    else if (!(formattedInputValue === cdContato) && validated) logicSetState({ type: 'validating', value: true });
    else if (!(formattedInputValue === cdContato) && validating) {
      setState((states) => ({ 
        ...states, 
        idContato: '', 
        validated: false, 
        validating: false, 
        code: '', 
        message: messageInitialState 
      }));
    }
  }, [formattedInputValue, cdContato, validated, validating]);
  useEffect(() => checkConsistency(), [formattedInputValue, checkConsistency]);

  useEffect(() => {
    (typeof getComponentData === 'function') && getComponentData(state);
  }, [state, getComponentData]);


  return <Grid container direction='column' {...{ id, className }} style={{ ...style, ...containerStyle }}>
    <TextField 
      {...textFieldProps} 
      disabled={disabledRule} 
      value={inputValue} 
      onChange={handleOnChange} 
      InputProps={{ 
        ...textFieldProps?.InputProps, 
        inputComponent: (cellphoneType) ? cellphoneMaskedInput : undefined, 
        endAdornment: (
          <InputAdornment position='end' style={endInputAdornmentStyle}>
            {(validatedRule) && <IoMdCheckmark color={GREEN_COLOR} size={INPUT_ADORNMENT_ICON_SIZE} />}
            {(noValidatedRule) && <LiaExclamationTriangleSolid color={ORANGE_COLOR} size={INPUT_ADORNMENT_ICON_SIZE} />}
            {(loading.input) && <CircularProgress color='secondary' size={INPUT_ADORNMENT_ICON_SIZE} />}
            {(noValidatedRule) && (
              <Button 
                size='small' 
                variant='contained' 
                disableElevation 
                disabled={disabledRule || loading.validation || sendValidationCodeButtonDisabled} 
                onClick={sendValidationCode}
              >
                Validar
              </Button>
            )}
          </InputAdornment>
        ) 
      }} 
    />
    {(message.text) && (
      <div>
        <Typography style={messageStyle}>
          {message.text}
        </Typography>
      </div>
    )}
    {(codeWasSent) && (
      <>
        <div className='otp-input-container'>
          <OtpInput 
            autoFocus 
            numInputs={5} 
            disabled={disabledRule || loading.validation} 
            value={code} 
            onChange={(newCode) => logicSetState({ type: 'code', value: newCode })} 
          />
        </div>
        <Grid container alignItems='center' style={validateCodeButtonsContainerStyle}>
          <IconButton 
            title='Chancelar' 
            tabIndex='1' 
            size='small' 
            disabled={disabledRule || loading.validation || loading.sendValidationLink} 
            onClick={toSeal} 
            style={sealButtonStyle}
          >
            <SealIcon />
          </IconButton>
          <Button 
            color='primary' 
            variant='contained' 
            disableElevation 
            disabled={disabledRule || loading.validation || loading.sendValidationLink || (code.length < 5)} 
            startIcon={(loading.validation) ? <CircularProgress color='secondary' size={20} /> : null} 
            onClick={validateCode} 
            style={validateCodeButtonStyle}
          >
            Validar código
          </Button>
        </Grid>
        {(emailType) && (
          <Button 
            variant='contained' 
            disableElevation 
            disabled={disabledRule || loading.validation || loading.sendValidationLink} 
            startIcon={(loading.sendValidationLink) ? <CircularProgress color='secondary' size={20} /> : null} 
            onClick={sendValidationLink}
          >
            Enviar link para validação no e-mail
          </Button>
        )}
      </>
    )}
  </Grid>;
};


export default ContactValidationInput;

==> argous-1.2.236.tgz: package/lib/components/ContactValidationInput/ContactValidationInput.js <==
import './style.css';
import SealModal from './SealModal';
import { OtpInput } from '../';
import { api, headers } from '../../api';
import { numbersOnly, useModal } from '../../utils';
import { setError } from '../../utils/api';
import { Button, CircularProgress, Grid, IconButton, InputAdornment, TextField, Typography, useTheme } from '@material-ui/core';
import React, { useCallback, useEffect, useRef, useState } from 'react';
import { IoMdCheckmark } from 'react-icons/io';
import { LiaExclamationTriangleSolid } from 'react-icons/lia';
import { PiSealCheck } from 'react-icons/pi';
import MaskedInput from 'react-maskedinput';


const EMAIL_VALIDATION_REGEX = /^[\w-.]+@([\w-]+\.)+[\w-]{2,4}$/;

const cellphoneMaskedInput = (props) => <MaskedInput mask='(11) 11111-1111' {...props} />;
export const SealIcon = PiSealCheck;

export const GREEN_COLOR = '#00995D';
const ORANGE_COLOR = '#f5781e';
const RED_COLOR = '#f44336';


const INPUT_ADORNMENT_ICON_SIZE = 18;


const loadingInitialState = { 
  input: false, 
  validation: false, 
  sendValidationLink: false 
};

const messageInitialState = { color: '', text: '' };

const initialState = { 
  loading: loadingInitialState, 
  validated: false, 
  validating: false, 
  searched: false, 
  idContato: '', 
  cdContato: '', 
  code: '', 
  message: messageInitialState 
};


const ContactValidationInput = ({ 
  id, 
  type = ('cellphone' || 'email'), 
  textFieldProps = {}, 
  style = {}, 
  className = '', 
  disabled, 
  cpf = '', 
  userName = '', 
  value = '', 
  onChange = () => '', 
  getComponentData = () => '' 
}) => {

  const theme = useTheme();
  const [state, setState] = useState({ ...initialState, inputValue: value });
  const { inputValue, loading, searched, validated, idContato, cdContato, code, message, validating } = state;
  const { createModal } = useModal();
  const sealModal = createModal(SealModal);
  const onChangeRef = useRef(onChange);

  const logicSetState = ({ type, field, value }) => setState((states) => ({ 
    ...states, 
    [type]: (type && field) ? { ...states[type], [field]: value } : value 
  }));

  const cellphoneType = (type === 'cellphone');
  const emailType = (type === 'email');

  const formattedInputValue = (cellphoneType) ? numbersOnly(inputValue) : inputValue;
  const invalidType = (!cellphoneType && !emailType);
  const disabledRule = (disabled || !cpf || !userName || invalidType || loading.input);
  const validatedRule = (searched && validated && !validating);
  const noValidatedRule = ((searched && !validated) || validating);
  const validCellphone = (cellphoneType && (formattedInputValue.length === 11));
  const validEmail = (emailType && (EMAIL_VALIDATION_REGEX.test(inputValue)));
  const sendValidationCodeButtonDisabled = (validCellphone || validEmail) ? false : true;
  const codeWasSent = !!idContato;


  const containerStyle = { gap: 10 };
  const endInputAdornmentStyle = { gap: 7 };

  const messageStyle = { 
    color: (message.color || theme.palette.text.primary), 
    fontStyle: 'italic' 
  };

  const validateCodeButtonsContainerStyle = { gap: 10 };

  const validateCodeButtonStyle = { 
    width: 'calc(100% - 36px - 10px)' 
  };

  const sealButtonStyle = { 
    height: '100%', 
    color: GREEN_COLOR, 
    border: `2px solid ${GREEN_COLOR}`, 
    borderRadius: 4, 
    padding: 5, 
    fontSize: 22 
  };


  const handleOnChange = useCallback((event) => {
    event.target.value = event.target.value.toString().toLowerCase();
    logicSetState({ type: 'inputValue', value: event.target.value });
    (typeof onChangeRef.current === 'function') && onChangeRef.current(event);
  }, []);

  const search = useCallback(async () => {
    if (invalidType) return;

    logicSetState({ type: 'loading', field: 'input', value: true });

    const parameters = { 
      method: 'S', 
      type: (cellphoneType) ? '1' : (emailType) ? '2' : '', 
      cdCpf: numbersOnly(cpf) 
    };

    const fetchOptions = { 
      method: 'POST', 
      body: JSON.stringify(parameters), 
      headers: headers() 
    };

    const { status, cdContato, isVerificado } = await fetch(`${api()}agscontactconfirmation.rslvr`, fetchOptions).then(async (response) => await response.json());
    if (status) {
      const newInputValue = (cdContato || '');

      setState((states) => ({ 
        ...states, 
        cdContato, 
        inputValue: newInputValue, 
        searched: true, 
        validated: isVerificado 
      }));

      let newEvent = new Event('search');
      Object.defineProperty(newEvent, 'target', { writable: false, value: { value: newInputValue } });
      handleOnChange(newEvent);
    }

    logicSetState({ type: 'loading', field: 'input', value: false });
  }, [cellphoneType, emailType, invalidType, cpf, handleOnChange]);

  useEffect(() => {
    search();
  }, [search]);

  const sendValidationCode = async () => {
    if (invalidType) return;

    logicSetState({ type: 'loading', field: 'input', value: true });

    const parameters = { 
      method: 'C', 
      type: (cellphoneType) ? '1' : (emailType) ? '2' : '', 
      tpMetodo: (emailType) ? '3' : '', 
      cdCpf: numbersOnly(cpf), 
      dsNome: userName, 
      cdContato: formattedInputValue 
    };

    const fetchOptions = { 
      method: 'POST', 
      body: JSON.stringify(parameters), 
      headers: headers() 
    };

    const { status, idContato, cdContato, dsErro } = await fetch(`${api()}agscontactconfirmation.rslvr`, fetchOptions).then(async (response) => await response.json());
    if (status) {
      setState((states) => ({ 
        ...states, 
        idContato, 
        cdContato, 
        validated: false, 
        validating: true, 
        message: { 
          color: ORANGE_COLOR, 
          text: (cellphoneType) ? 'Utilize o código recebido via sms' : (emailType) ? 'Utilize o código recebido via e-mail' : '' 
        } 
      }));
    } else {
      (dsErro) && setError(dsErro);
    }

    logicSetState({ type: 'loading', field: 'input', value: false });
  };

  const sendValidationLink = async () => {
    if (invalidType) return;

    logicSetState({ type: 'loading', field: 'sendValidationLink', value: true });

    const parameters = { 
      method: 'C', 
      type: '2', 
      tpMetodo: '4', 
      cdCpf: numbersOnly(cpf), 
      dsNome: userName, 
      cdContato: formattedInputValue 
    };

    const fetchOptions = { 
      method: 'POST', 
      body: JSON.stringify(parameters), 
      headers: headers() 
    };

    const { status, cdContato, dsErro } = await fetch(`${api()}agscontactconfirmation.rslvr`, fetchOptions).then(async (response) => await response.json());
    if (status) {
      setState((states) => ({ 
        ...states, 
        idContato: '', 
        cdContato, 
        code: '', 
        message: { 
          color: '', 
          text: `O link de validação foi enviado para o e-mail "${cdContato}"` 
        } 
      }));
    } else {
      (dsErro) && setError(dsErro);
    }

    logicSetState({ type: 'loading', field: 'sendValidationLink', value: false });
  };

  const validateCode = async ({ snChancela = false }) => {
    if (invalidType) return;

    logicSetState({ type: 'loading', field: (snChancela) ? 'input' : 'validation', value: true });

    const parameters = { 
      method: 'V', 
      type: (cellphoneType) ? '1' : (emailType) ? '2' : '', 
      cdCpf: numbersOnly(cpf), 
      dsNome: userName, 
      cdCode: code, 
      cdContato: formattedInputValue, 
      idContato, 
      snChancela 
    };

    const fetchOptions = { 
      method: 'POST', 
      body: JSON.stringify(parameters), 
      headers: headers() 
    };

    const { status, isVerificado } = await fetch(`${api()}agscontactconfirmation.rslvr`, fetchOptions).then(async (response) => await response.json());
    if (status) {

      let messageText = '';

      if (isVerificado) {
        if (cellphoneType) messageText = 'Celular validado com sucesso';
        else if (emailType) messageText = 'E-mail validado com sucesso';

        setTimeout(() => logicSetState({ type: 'message', value: messageInitialState }), 6000);
      } else {
        messageText = 'Código inválido. Por favor tente novamente.';
      }

      setState((states) => ({ 
        ...states, 
        validated: isVerificado, 
        validating: false, 
        idContato: '', 
        code: '', 
        message: { 
          color: (isVerificado) ? '' : RED_COLOR, 
          text: messageText 
        } 
      }));
    }

    logicSetState({ type: 'loading', field: (snChancela) ? 'input' : 'validation', value: false });
  };

  const toSeal = async () => {
    const { status } = await sealModal();
    if (status) validateCode({ snChancela: true });
  };

  const checkConsistency = useCallback(() => {
    if ((formattedInputValue === cdContato) && validated) logicSetState({ type: 'validating', value: false });
    else if (!(formattedInputValue === cdContato) && validated) logicSetState({ type: 'validating', value: true });
    else if (!(formattedInputValue === cdContato) && validating) {
      setState((states) => ({ 
        ...states, 
        idContato: '', 
        validated: false, 
        validating: false, 
        code: '', 
        message: messageInitialState 
      }));
    }
  }, [formattedInputValue, cdContato, validated, validating]);
  useEffect(() => checkConsistency(), [formattedInputValue, checkConsistency]);

  useEffect(() => {
    (typeof getComponentData === 'function') && getComponentData(state);
  }, [state, getComponentData]);


  return <Grid container direction='column' {...{ id, className }} style={{ ...style, ...containerStyle }}>
    <TextField 
      {...textFieldProps} 
      disabled={disabledRule} 
      value={inputValue} 
      onChange={handleOnChange} 
      InputProps={{ 
        ...textFieldProps?.InputProps, 
        inputComponent: (cellphoneType) ? cellphoneMaskedInput : undefined, 
        endAdornment: (
          <InputAdornment position='end' style={endInputAdornmentStyle}>
            {(validatedRule) && <IoMdCheckmark color={GREEN_COLOR} size={INPUT_ADORNMENT_ICON_SIZE} />}
            {(noValidatedRule) && <LiaExclamationTriangleSolid color={ORANGE_COLOR} size={INPUT_ADORNMENT_ICON_SIZE} />}
            {(loading.input) && <CircularProgress color='secondary' size={INPUT_ADORNMENT_ICON_SIZE} />}
            {(noValidatedRule) && (
              <Button 
                size='small' 
                variant='contained' 
                disableElevation 
                disabled={disabledRule || loading.validation || sendValidationCodeButtonDisabled} 
                onClick={sendValidationCode}
              >
                Validar
              </Button>
            )}
          </InputAdornment>
        ) 
      }} 
    />
    {(message.text) && (
      <div>
        <Typography style={messageStyle}>
          {message.text}
        </Typography>
      </div>
    )}
    {(codeWasSent) && (
      <>
        <div className='otp-input-container'>
          <OtpInput 
            autoFocus 
            numInputs={5} 
            disabled={disabledRule || loading.validation} 
            value={code} 
            onChange={(newCode) => logicSetState({ type: 'code', value: newCode })} 
          />
        </div>
        <Grid container alignItems='center' style={validateCodeButtonsContainerStyle}>
          <IconButton 
            title='Chancelar' 
            tabIndex='1' 
            size='small' 
            disabled={disabledRule || loading.validation || loading.sendValidationLink} 
            onClick={toSeal} 
            style={sealButtonStyle}
          >
            <SealIcon />
          </IconButton>
          <Button 
            color='primary' 
            variant='contained' 
            disableElevation 
            disabled={disabledRule || loading.validation || loading.sendValidationLink || (code.length < 5)} 
            startIcon={(loading.validation) ? <CircularProgress color='secondary' size={20} /> : null} 
            onClick={validateCode} 
            style={validateCodeButtonStyle}
          >
            Validar código
          </Button>
        </Grid>
        {(emailType) && (
          <Button 
            variant='contained' 
            disableElevation 
            disabled={disabledRule || loading.validation || loading.sendValidationLink} 
            startIcon={(loading.sendValidationLink) ? <CircularProgress color='secondary' size={20} /> : null} 
            onClick={sendValidationLink}
          >
            Enviar link para validação no e-mail
          </Button>
        )}
      </>
    )}
  </Grid>;
};


export default ContactValidationInput;
